@@ -47,8 +47,7 @@ juego :: juego()
 	puntos = 0;
 	vidas = 3;
 	tiempo_bonus = 0;
-	strcpy (nombre, _("here"));
-	delay_tecla = 0;
+	strcpy (nombre, (""));
 	proximo_pago_vida = 300;
 }
 
@@ -480,7 +479,16 @@ void juego :: restar_vidas(void)
 		procesos->pausar_gaucho();
 		procesos->pausar_tiros();
 		procesos->pausar_enemigos();
-		cambiar_estado(PIERDE_TODO);
+		if (es_marca(puntos))
+		{
+		    pmundo->deshabilitar_letras();
+		    cambiar_estado(GUARDA_MARCA);
+                    return;
+		}
+                else
+                {
+		    cambiar_estado(PIERDE_TODO);
+                }
 	}
 	else
 	{
@@ -682,16 +690,7 @@ void juego :: pierde_todo(void)
 	{
 		if (tecla[SDLK_ESCAPE])
 		{
-			if (es_marca(puntos))
-			{
-				cambiar_estado(GUARDA_MARCA);
-				pmundo->deshabilitar_letras();
-			}
-			else
-			{
-				pmundo->cambiar_escena(MENU);
-			}
-
+		    	pmundo->cambiar_escena(MENU);
 			return;
 		}
 
@@ -826,7 +825,7 @@ void juego :: guarda_marca(void)
 				pmundo->habilitar_letras();
 				
 				if (vidas<0)
-					pmundo->cambiar_escena(MENU);
+		                        cambiar_estado(PIERDE_TODO);
 				else
 					pmundo->cambiar_escena(FINAL);
 					
@@ -842,7 +841,7 @@ void juego :: guarda_marca(void)
 			pmundo->habilitar_letras();
 
 			if (vidas<0)
-				pmundo->cambiar_escena(MARCAS);
+		                cambiar_estado(PIERDE_TODO);
 			else
 				pmundo->cambiar_escena(FINAL);
 
